@@ -29,6 +29,7 @@ def S_{filename}():
     job = ETL_FILE_PATH + '{project_name}/{filename}.py'
     result=os.system('python %s %s'%(job,{param}))
     if result !=0:
+        fun_email(f'{project_name}/{filename}出错', 'python error')
         raise Exception('error')
 '''
 # 0 - project_name, 1 - kettle tranform name, 2 - para string
@@ -63,6 +64,14 @@ def S_{filename}():
     run_kettle_remote(job,{param_str},dev=dev)
 '''
 
+execute_hdfs_format = '''
+# execute kettle with hdfs job
+def S_{filename}():
+    job=ETL_FILE_PATH + '{project_name}/{filename}.ktr'
+    run_kettle(job,{param_str},dev=dev)
+    load_hive(job)
+'''
+
 # 0 - project_name, 1 - sql script name,
 execute_sql_format = '''
 # execute db sql script
@@ -98,7 +107,7 @@ execute_sap_format = '''
 # execute sap rfc script
 def S_{filename}():
     path = ETL_FILE_PATH + '{project_name}/{filename}.json'
-    run_rfc_python(path, {param})
+    run_rfc(path, {param})
 '''
 
 param_str_format = ''' ' "-param:{item_param}={{}}"'.format({item_param}) '''
@@ -169,6 +178,10 @@ dag_jobs_format_trigger = '''
 {filename}.driver = '{driver}'
 '''
 
+dag_jobs_format_queue = '''
+{filename}.queue = 'bg'
+'''
+
 # breaking_point
 execute_point_format = '''
 # decide Continue or terminate
